From 87b2663ac100c053300bf77bad5c886b5b4e6c6c Mon Sep 17 00:00:00 2001
From: JGHFunRun <52897905+JGHFunRun@users.noreply.github.com>
Date: Sun, 3 Apr 2022 06:07:58 -0500
Subject: [PATCH] No "tb303" only "TB-303" (#6344)
---
data/locale/ar.ts | 4 ++--
data/locale/bs.ts | 4 ++--
data/locale/ca.ts | 6 +++---
data/locale/cs.ts | 6 +++---
data/locale/de.ts | 4 ++--
data/locale/el.ts | 4 ++--
data/locale/en.ts | 2 +-
data/locale/eo.ts | 4 ++--
data/locale/es.ts | 6 +++---
data/locale/eu.ts | 4 ++--
data/locale/fa.ts | 4 ++--
data/locale/fr.ts | 6 +++---
data/locale/gl.ts | 6 +++---
data/locale/he.ts | 4 ++--
data/locale/hi_IN.ts | 4 ++--
data/locale/hu_HU.ts | 6 +++---
data/locale/id.ts | 4 ++--
data/locale/it.ts | 6 +++---
data/locale/ja.ts | 4 ++--
data/locale/ka.ts | 4 ++--
data/locale/ko.ts | 4 ++--
data/locale/ms_MY.ts | 4 ++--
data/locale/nb.ts | 4 ++--
data/locale/nl.ts | 6 +++---
data/locale/oc.ts | 4 ++--
data/locale/pl.ts | 6 +++---
data/locale/pt.ts | 6 +++---
data/locale/ro.ts | 4 ++--
data/locale/ru.ts | 6 +++---
data/locale/sl.ts | 4 ++--
data/locale/sr.ts | 4 ++--
data/locale/sv.ts | 6 +++---
data/locale/tr.ts | 6 +++---
data/locale/uk.ts | 6 +++---
data/locale/zh_CN.ts | 6 +++---
data/locale/zh_TW.ts | 4 ++--
plugins/lb302/README | 2 +-
plugins/lb302/lb302.cpp | 6 +++---
plugins/lb302/lb302.h | 4 ++--
39 files changed, 92 insertions(+), 92 deletions(-)
diff --git a/data/locale/ar.ts b/data/locale/ar.ts
index 9906aea95..fc8969576 100644
--- a/data/locale/ar.ts
+++ b/data/locale/ar.ts
@@ -10283,7 +10283,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16324,4 +16324,4 @@ Please make sure you have read-permission to the file and the directory containi
-
\ No newline at end of file
+
diff --git a/data/locale/bs.ts b/data/locale/bs.ts
index f8f54c722..ff38bd042 100644
--- a/data/locale/bs.ts
+++ b/data/locale/bs.ts
@@ -11406,7 +11406,7 @@ Double clicking any of the plugins will bring up information on the ports.
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -12427,4 +12427,4 @@ The LED in the lower right corner of the waveform editor determines whether the
-
\ No newline at end of file
+
diff --git a/data/locale/ca.ts b/data/locale/ca.ts
index be8c6b16b..bfcfaecbb 100644
--- a/data/locale/ca.ts
+++ b/data/locale/ca.ts
@@ -10282,8 +10282,8 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
- Imitació monofònica incompleta tb303
+ Incomplete monophonic imitation TB-303
+ Imitació monofònica incompleta TB-303
@@ -16323,4 +16323,4 @@ Please make sure you have read-permission to the file and the directory containi
-
\ No newline at end of file
+
diff --git a/data/locale/cs.ts b/data/locale/cs.ts
index 5105efbb1..6aa72733e 100644
--- a/data/locale/cs.ts
+++ b/data/locale/cs.ts
@@ -10287,8 +10287,8 @@ Důvod: "%2"
- Incomplete monophonic imitation tb303
- Nekompletní monofonní imitace tb303
+ Incomplete monophonic imitation TB-303
+ Nekompletní monofonní imitace TB-303
@@ -16333,4 +16333,4 @@ Přesvědčte se prosím, že máte právo ke čtení tohoto souboru a příslu
Zesílení výstupu
-
\ No newline at end of file
+
diff --git a/data/locale/de.ts b/data/locale/de.ts
index e920beed0..d21dd82cc 100644
--- a/data/locale/de.ts
+++ b/data/locale/de.ts
@@ -10286,7 +10286,7 @@ Grund: »%2«
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303Unvollständiger monophonischer TB303-Klon
@@ -16331,4 +16331,4 @@ Bitte stellen Sie sicher, dass Sie Leserechte auf diese Datei sowie das Verzeich
Ausgabeverstärkung
-
\ No newline at end of file
+
diff --git a/data/locale/el.ts b/data/locale/el.ts
index 79724dc26..151aefb0f 100644
--- a/data/locale/el.ts
+++ b/data/locale/el.ts
@@ -10282,7 +10282,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16323,4 +16323,4 @@ Please make sure you have read-permission to the file and the directory containi
Απολαβή εξόδου
-
\ No newline at end of file
+
diff --git a/data/locale/en.ts b/data/locale/en.ts
index 4a77d8db9..f2db79b1d 100644
--- a/data/locale/en.ts
+++ b/data/locale/en.ts
@@ -10284,7 +10284,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
diff --git a/data/locale/eo.ts b/data/locale/eo.ts
index 61fcbd54b..f09e5f11a 100644
--- a/data/locale/eo.ts
+++ b/data/locale/eo.ts
@@ -10282,7 +10282,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16323,4 +16323,4 @@ Please make sure you have read-permission to the file and the directory containi
-
\ No newline at end of file
+
diff --git a/data/locale/es.ts b/data/locale/es.ts
index 753c4c35c..bff0c9628 100644
--- a/data/locale/es.ts
+++ b/data/locale/es.ts
@@ -10286,8 +10286,8 @@ Razón: "%2"
- Incomplete monophonic imitation tb303
- Imitación monofónica incompleta del tb303
+ Incomplete monophonic imitation TB-303
+ Imitación monofónica incompleta del TB-303
@@ -16332,4 +16332,4 @@ Please make sure you have read-permission to the file and the directory containi
ganancia de salida
-
\ No newline at end of file
+
diff --git a/data/locale/eu.ts b/data/locale/eu.ts
index 022c25322..a0a3e505e 100644
--- a/data/locale/eu.ts
+++ b/data/locale/eu.ts
@@ -10563,7 +10563,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16604,4 +16604,4 @@ Please make sure you have read-permission to the file and the directory containi
Irteerako irabazia
-
\ No newline at end of file
+
diff --git a/data/locale/fa.ts b/data/locale/fa.ts
index ba975e933..66d0e0baa 100644
--- a/data/locale/fa.ts
+++ b/data/locale/fa.ts
@@ -10282,7 +10282,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16323,4 +16323,4 @@ Please make sure you have read-permission to the file and the directory containi
افزایش خروجی
-
\ No newline at end of file
+
diff --git a/data/locale/fr.ts b/data/locale/fr.ts
index 667d204ee..066921631 100644
--- a/data/locale/fr.ts
+++ b/data/locale/fr.ts
@@ -10578,8 +10578,8 @@ Raison : "%2"
- Incomplete monophonic imitation tb303
- Imitation incomplète de TB303 monophonique
+ Incomplete monophonic imitation TB-303
+ Imitation incomplète de TB-303 monophonique
@@ -16624,4 +16624,4 @@ Veuillez vérifier que vous avez les droits en lecture pour ce fichier et le ré
Gain en sortie
-
\ No newline at end of file
+
diff --git a/data/locale/gl.ts b/data/locale/gl.ts
index 0efa2ea42..2c35f8712 100644
--- a/data/locale/gl.ts
+++ b/data/locale/gl.ts
@@ -10284,8 +10284,8 @@ Razón: «%2»
- Incomplete monophonic imitation tb303
- Imitación monofónica incompleta tb303
+ Incomplete monophonic imitation TB-303
+ Imitación monofónica incompleta TB-303
@@ -16326,4 +16326,4 @@ Please make sure you have read-permission to the file and the directory containi
-
\ No newline at end of file
+
diff --git a/data/locale/he.ts b/data/locale/he.ts
index d224c2803..2cea85107 100644
--- a/data/locale/he.ts
+++ b/data/locale/he.ts
@@ -10283,7 +10283,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16324,4 +16324,4 @@ Please make sure you have read-permission to the file and the directory containi
-
\ No newline at end of file
+
diff --git a/data/locale/hi_IN.ts b/data/locale/hi_IN.ts
index d55cd895e..6f2bfaab0 100644
--- a/data/locale/hi_IN.ts
+++ b/data/locale/hi_IN.ts
@@ -10284,7 +10284,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16325,4 +16325,4 @@ Please make sure you have read-permission to the file and the directory containi
-
\ No newline at end of file
+
diff --git a/data/locale/hu_HU.ts b/data/locale/hu_HU.ts
index 53f6e4d73..b2f4d65a9 100644
--- a/data/locale/hu_HU.ts
+++ b/data/locale/hu_HU.ts
@@ -10292,8 +10292,8 @@ Ok: "%2"
- Incomplete monophonic imitation tb303
- Félkész monofonikus tb303 imitáció
+ Incomplete monophonic imitation TB-303
+ Félkész monofonikus TB-303 imitáció
@@ -16336,4 +16336,4 @@ Please make sure you have read-permission to the file and the directory containi
Kimeneti erősítés
-
\ No newline at end of file
+
diff --git a/data/locale/id.ts b/data/locale/id.ts
index e65d2fa53..71b71e3d3 100644
--- a/data/locale/id.ts
+++ b/data/locale/id.ts
@@ -10291,7 +10291,7 @@ Alasan: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16340,4 +16340,4 @@ Pastikan anda memiliki izin baca untuk berkas ini dan direktori yang mengandung
Gain keluaran
-
\ No newline at end of file
+
diff --git a/data/locale/it.ts b/data/locale/it.ts
index b1b6beb7d..4488a3021 100644
--- a/data/locale/it.ts
+++ b/data/locale/it.ts
@@ -10299,8 +10299,8 @@ Motivo: "%2"
- Incomplete monophonic imitation tb303
- Imitazione monofonica del tb303 incompleta
+ Incomplete monophonic imitation TB-303
+ Imitazione monofonica del TB-303 incompleta
@@ -16348,4 +16348,4 @@ Assicurarsi di avere i permessi in lettura per il file e per la directory che lo
Guadagno in output
-
\ No newline at end of file
+
diff --git a/data/locale/ja.ts b/data/locale/ja.ts
index 33a988993..17c56aa43 100644
--- a/data/locale/ja.ts
+++ b/data/locale/ja.ts
@@ -10287,7 +10287,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16332,4 +16332,4 @@ Please make sure you have read-permission to the file and the directory containi
出力ゲイン
-
\ No newline at end of file
+
diff --git a/data/locale/ka.ts b/data/locale/ka.ts
index 7e1187a26..198f87361 100644
--- a/data/locale/ka.ts
+++ b/data/locale/ka.ts
@@ -10282,7 +10282,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16323,4 +16323,4 @@ Please make sure you have read-permission to the file and the directory containi
-
\ No newline at end of file
+
diff --git a/data/locale/ko.ts b/data/locale/ko.ts
index 2829c1983..9b52317da 100644
--- a/data/locale/ko.ts
+++ b/data/locale/ko.ts
@@ -10289,7 +10289,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16332,4 +16332,4 @@ Please make sure you have read-permission to the file and the directory containi
출력 이득
-
\ No newline at end of file
+
diff --git a/data/locale/ms_MY.ts b/data/locale/ms_MY.ts
index ab477a55d..2deab4f87 100644
--- a/data/locale/ms_MY.ts
+++ b/data/locale/ms_MY.ts
@@ -10282,7 +10282,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16323,4 +16323,4 @@ Please make sure you have read-permission to the file and the directory containi
Kekuatan keluar
-
\ No newline at end of file
+
diff --git a/data/locale/nb.ts b/data/locale/nb.ts
index 0fd155a47..9df82d513 100644
--- a/data/locale/nb.ts
+++ b/data/locale/nb.ts
@@ -10283,7 +10283,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16324,4 +16324,4 @@ Please make sure you have read-permission to the file and the directory containi
-
\ No newline at end of file
+
diff --git a/data/locale/nl.ts b/data/locale/nl.ts
index d93dc25b0..cd8524dc8 100644
--- a/data/locale/nl.ts
+++ b/data/locale/nl.ts
@@ -10288,8 +10288,8 @@ Reden: "%2"
- Incomplete monophonic imitation tb303
- Onvoltooide monofonische limitering tb303
+ Incomplete monophonic imitation TB-303
+ Onvoltooide monofonische limitering TB-303
@@ -16334,4 +16334,4 @@ Verzeker u ervan dat u leesrechten heeft voor het bestand en zijn bevattende map
Uitvoer-gain
-
\ No newline at end of file
+
diff --git a/data/locale/oc.ts b/data/locale/oc.ts
index b0841d0e5..14fea1e0f 100644
--- a/data/locale/oc.ts
+++ b/data/locale/oc.ts
@@ -10282,7 +10282,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16323,4 +16323,4 @@ Please make sure you have read-permission to the file and the directory containi
Ganh en sortida
-
\ No newline at end of file
+
diff --git a/data/locale/pl.ts b/data/locale/pl.ts
index de980a700..165801666 100644
--- a/data/locale/pl.ts
+++ b/data/locale/pl.ts
@@ -10571,8 +10571,8 @@ Powód: "%2"
- Incomplete monophonic imitation tb303
- Niezupełna monofoniczna emulacja syntezatora tb303.
+ Incomplete monophonic imitation TB-303
+ Niezupełna monofoniczna emulacja syntezatora TB-303.
@@ -16619,4 +16619,4 @@ Upewnij się, że masz uprawnienia do odczytu tego pliku i katalogu zawierające
Wzmocnienie wyścia
-
\ No newline at end of file
+
diff --git a/data/locale/pt.ts b/data/locale/pt.ts
index ad06701e0..8ecc87f1c 100644
--- a/data/locale/pt.ts
+++ b/data/locale/pt.ts
@@ -10287,8 +10287,8 @@ Motivo: "%2"
- Incomplete monophonic imitation tb303
- Imitação monofônica incompleta de tb303
+ Incomplete monophonic imitation TB-303
+ Imitação monofônica incompleta de TB-303
@@ -16332,4 +16332,4 @@ Por favor certifique-se que você tem permissões de leitura para o arquivo e pa
Ganho de saída
-
\ No newline at end of file
+
diff --git a/data/locale/ro.ts b/data/locale/ro.ts
index 2aeafe9ab..db32b6ad3 100644
--- a/data/locale/ro.ts
+++ b/data/locale/ro.ts
@@ -10283,7 +10283,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16324,4 +16324,4 @@ Please make sure you have read-permission to the file and the directory containi
-
\ No newline at end of file
+
diff --git a/data/locale/ru.ts b/data/locale/ru.ts
index e611c20f2..3216aaad4 100644
--- a/data/locale/ru.ts
+++ b/data/locale/ru.ts
@@ -10309,8 +10309,8 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
- Незавершённая монофоническая имитация tb303
+ Incomplete monophonic imitation TB-303
+ Незавершённая монофоническая имитация TB-303
@@ -16359,4 +16359,4 @@ Please make sure you have read-permission to the file and the directory containi
Выходная мощность
-
\ No newline at end of file
+
diff --git a/data/locale/sl.ts b/data/locale/sl.ts
index 6c960f20a..73179d7f2 100644
--- a/data/locale/sl.ts
+++ b/data/locale/sl.ts
@@ -10282,7 +10282,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16323,4 +16323,4 @@ Please make sure you have read-permission to the file and the directory containi
-
\ No newline at end of file
+
diff --git a/data/locale/sr.ts b/data/locale/sr.ts
index 1208a8a96..5db09a6e8 100644
--- a/data/locale/sr.ts
+++ b/data/locale/sr.ts
@@ -8962,7 +8962,7 @@ Double clicking any of the plugins will bring up information on the ports.
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -9856,4 +9856,4 @@ The LED in the lower right corner of the waveform editor determines whether the
-
\ No newline at end of file
+
diff --git a/data/locale/sv.ts b/data/locale/sv.ts
index acf905486..d814b3815 100644
--- a/data/locale/sv.ts
+++ b/data/locale/sv.ts
@@ -10577,8 +10577,8 @@ Orsak: "%2"
- Incomplete monophonic imitation tb303
- Ofullstädig monofonisk imitation av tb303
+ Incomplete monophonic imitation TB-303
+ Ofullstädig monofonisk imitation av TB-303
@@ -16626,4 +16626,4 @@ Se till att du har läsrättigheter för filen och mappen som innehåller filen
Utgångsförstärkning
-
\ No newline at end of file
+
diff --git a/data/locale/tr.ts b/data/locale/tr.ts
index d97cbd953..ddee3f10b 100644
--- a/data/locale/tr.ts
+++ b/data/locale/tr.ts
@@ -10579,8 +10579,8 @@ Nedeni: "%2"
- Incomplete monophonic imitation tb303
- Eksik monofonik taklit tb303
+ Incomplete monophonic imitation TB-303
+ Eksik monofonik taklit TB-303
@@ -16628,4 +16628,4 @@ Lütfen dosyayı ve dosyayı içeren dizini okuma iznine sahip olduğunuzdan emi
Çıkış kazancı
-
\ No newline at end of file
+
diff --git a/data/locale/uk.ts b/data/locale/uk.ts
index ff4061f5f..892deab3c 100644
--- a/data/locale/uk.ts
+++ b/data/locale/uk.ts
@@ -10286,8 +10286,8 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
- Незавершена монофонічна імітація tb303
+ Incomplete monophonic imitation TB-303
+ Незавершена монофонічна імітація TB-303
@@ -16332,4 +16332,4 @@ Please make sure you have read-permission to the file and the directory containi
Вихідне підсилення
-
\ No newline at end of file
+
diff --git a/data/locale/zh_CN.ts b/data/locale/zh_CN.ts
index d7e5632af..85eecb856 100644
--- a/data/locale/zh_CN.ts
+++ b/data/locale/zh_CN.ts
@@ -10296,8 +10296,8 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
- 对单音 TB303 的不完整的模拟器
+ Incomplete monophonic imitation TB-303
+ 对单音 TB-303 的不完整的模拟器
@@ -16342,4 +16342,4 @@ Please make sure you have read-permission to the file and the directory containi
输出增益
-
\ No newline at end of file
+
diff --git a/data/locale/zh_TW.ts b/data/locale/zh_TW.ts
index 45c9436c0..966891479 100644
--- a/data/locale/zh_TW.ts
+++ b/data/locale/zh_TW.ts
@@ -10286,7 +10286,7 @@ Reason: "%2"
- Incomplete monophonic imitation tb303
+ Incomplete monophonic imitation TB-303
@@ -16332,4 +16332,4 @@ Please make sure you have read-permission to the file and the directory containi
輸出增益
-
\ No newline at end of file
+
diff --git a/plugins/lb302/README b/plugins/lb302/README
index 7ed09a0c1..c2ef038ca 100644
--- a/plugins/lb302/README
+++ b/plugins/lb302/README
@@ -56,7 +56,7 @@ TODO:
in order to apply the built-in exponential decay.
TODO:
- The original TB303's square wave is not 50% duty cycle. The peaks are
+ The original TB-303's square wave is not 50% duty cycle. The peaks are
supposed to slope down slightly. It would be nice to be able to
configure this. In fact, each waveform could have a parameter knob to
change some aspect of the wave. See lb302.cpp:643 for more info.
diff --git a/plugins/lb302/lb302.h b/plugins/lb302/lb302.h
index 62b357377..a7df757d6 100644
--- a/plugins/lb302/lb302.h
+++ b/plugins/lb302/lb302.h
@@ -1,6 +1,6 @@
/*
* lb302.h - declaration of class lb302 which is a bass synth attempting to
- * emulate the Roland TB303 bass synth
+ * emulate the Roland TB-303 bass synth
*
* Copyright (c) 2006-2008 Paul Giblock
*
@@ -8,7 +8,7 @@
*
* lb302FilterIIR2 is based on the gsyn filter code by Andy Sloane.
*
- * lb302Filter3Pole is based on the TB303 instrument written by
+ * lb302Filter3Pole is based on the TB-303 instrument written by
* Josep M Comajuncosas for the CSounds library
*
* This program is free software; you can redistribute it and/or
diff --git a/plugins/lb302/lb302.cpp b/plugins/lb302/lb302.cpp
index 8e19dae90..aef1c00d9 100644
--- a/plugins/lb302/lb302.cpp
+++ b/plugins/lb302/lb302.cpp
@@ -1,6 +1,6 @@
/*
* lb302.cpp - implementation of class lb302 which is a bass synth attempting
* to emulate the Roland TB303 bass synth
*
* Copyright (c) 2006-2008 Paul Giblock
*
@@ -8,7 +8,7 @@
*
* lb302FilterIIR2 is based on the gsyn filter code by Andy Sloane.
*
* lb302Filter3Pole is based on the TB303 instrument written by
* Josep M Comajuncosas for the CSounds library
*
* This program is free software; you can redistribute it and/or
@@ -81,7 +81,7 @@ Plugin::Descriptor PLUGIN_EXPORT lb302_plugin_descriptor =
STRINGIFY( PLUGIN_NAME ),
"LB302",
QT_TRANSLATE_NOOP( "PluginBrowser",
- "Incomplete monophonic imitation tb303" ),
+ "Incomplete monophonic imitation TB-303" ),
"Paul Giblock ",
0x0100,
Plugin::Instrument,
@@ -1,6 +1,6 @@
/*
* lb302.cpp - implementation of class lb302 which is a bass synth attempting
- * to emulate the Roland TB303 bass synth
+ * to emulate the Roland TB-303 bass synth
*
* Copyright (c) 2006-2008 Paul Giblock
@@ -8,7 +8,7 @@
* lb302FilterIIR2 is based on the gsyn filter code by Andy Sloane.
*
- * lb302Filter3Pole is based on the TB303 instrument written by
+ * lb302Filter3Pole is based on the TB-303 instrument written by
* Josep M Comajuncosas for the CSounds library
*